@@ -17,9 +17,12 @@ struct kanshi_profile_output {
 	char *name;
 	unsigned int fields; // enum kanshi_output_field
 	struct wl_list link;
+	bool any_number; // "...output" directive
 
 	bool enabled;
 	struct {
+		bool preferred;
+
 		int width, height;
 		int refresh; // mHz
 		bool custom;
